/*
 *	Filename:		clutils.h
 *	Description:	Definitions for the useful command line routines
 */

#ifndef CLUTILS_H
#define CLUTILS_H

/* Range of permissable colours in a Win32 console, and a type name for them */
enum ConsoleColourEnum
{
	CONSOLE_COLOR_NOCHANGE = -1,
	CONSOLE_COLOR_BLACK,
	CONSOLE_COLOR_BLUE,
	CONSOLE_COLOR_RED,
	CONSOLE_COLOR_GREEN,
	CONSOLE_COLOR_MAGENTA,
	CONSOLE_COLOR_CYAN,
	CONSOLE_COLOR_YELLOW,
	CONSOLE_COLOR_WHITE,
	CONSOLE_COLOR_GREY,
	CONSOLE_COLOR_BRIGHT_BLUE,
	CONSOLE_COLOR_BRIGHT_RED,
	CONSOLE_COLOR_BRIGHT_GREEN,
	CONSOLE_COLOR_BRIGHT_MAGENTA,
	CONSOLE_COLOR_BRIGHT_CYAN,
	CONSOLE_COLOR_BRIGHT_YELLOW,
	CONSOLE_COLOR_BRIGHT_WHITE
};
typedef enum ConsoleColourEnum	ConsoleColourType;


void				clrscr(void);																/* Clears console screen */
void				ConsoleLocate(int x, int y);												/* Sets cursor X/Y position */
void				ConsolePosition(int *x, int *y);											/* Returns cursor X/Y position */
void				ConsoleColour(ConsoleColourType foreground, ConsoleColourType background);	/* Set foreground and background colours */
ConsoleColourType	ConsoleForeground(void);													/* Return current foreground colour */
ConsoleColourType	ConsoleBackground(void);													/* Return current background colour */
int					ConsoleInverse(int x, int y, int width, int height);						/* Inverse-videos an area of a console */
int					kbhit(void);																/* Checks to see whether there have been any new keypresses in a console */
int					getline(char *line_buffer, int buffer_length);								/* Reads a line from the keyboard, allowing initial CRLFs to terminate the read */


/* Character codes for extended characters while using the program */
#define KEYCODE_UPARROW		72
#define KEYCODE_DOWNARROW	80
#define KEYCODE_LEFTARROW	75
#define KEYCODE_RIGHTARROW	77
#define KEYCODE_PAGEUP		73
#define KEYCODE_PAGEDOWN	81
#define KEYCODE_HOME		71
#define KEYCODE_END			79
#define KEYCODE_ESCAPE		27
#define KEYCODE_F1			59
#define KEYCODE_F2			60
#define KEYCODE_F3			61
#define KEYCODE_F4			62
#define KEYCODE_F5			63
#define KEYCODE_F6			64
#define KEYCODE_F7			65
#define KEYCODE_F8			66


#endif /* CLUTILS_H */

