/*
 *	Filename:		debug.h
 *	Description:	Definitions for debugging functions. You should define the symbol
 *					"DEBUG" in your project options if you want to use the debugging
 *					macros and functions and have them do anything useful. The reason
 *					for doing it in your project options is so that it has global
 *					definition scope, although I suppose it would be possible to do
 *					it on a per-unit basis.
 *
 *					Define it as 0 for no debugging (-DDEBUG=0)
 *					define it as 1 for only d2() level debugging (-DDEBUG=1)
 *					define it as 2 for all (d1() and d2()) level debugging (-DDEBUG=2)
 *
 *					Typically you would only use 0 or 1.
 *	Example:
 *	
 *		d2(kprintf("%s - " __FILE__ "/%s/%d: \n", kmodulename(), FUNCNAME, __LINE__));
 *
 *	To do:			
 */


#ifndef DEBUG_H
#define DEBUG_H

#if defined(__cplusplus)
extern "C" {
#endif

#if !defined(DEBUG)
#define DEBUG	0
#endif

/* For uniformity of debug statements */
#if defined(__GNUC__)
 #define FUNCNAME __func__
#else
 #define FUNCNAME __FUNC__
#endif

#if DEBUG==0
#define d1(x)
#define d2(x)
#elif DEBUG==1
#define d1(x)
#define d2(x) x
int kprintf(const char *format, ...);
const char *kmodulename(void);
#elif DEBUG==2
#define d1(x) x
#define d2(x) x
int	kprintf(const char *format, ...);
const char *kmodulename(void);
#endif

#if defined(__cplusplus)
}
#endif

#endif /* DEBUG_H */

